@@ -154,7 +154,8 @@ interactive_time () {
                 "return" "Looks good. back to main menu" "${EXTRA[@]}" "manual" "Set time and date manually" || return 1
                 if [ "$ANSWER_OPTION" = ntp ]
                 then
-			if ntpdate pool.ntp.org >/dev/null 
+			infofy "Syncing clock with internet pool ..."
+			if ntpdate pool.ntp.org >/dev/null
 			then
 				notify "Synced clock with internet pool successfully."
 				dohwclock $HARDWARECLOCK systohc && NEXTITEM=3
@@ -164,7 +165,7 @@ interactive_time () {
 		fi
 		if [ "$ANSWER_OPTION" = manual ]
 		then
-			ask_datetime 
+			ask_datetime || continue
 			if date -s "$ANSWER_DATETIME"
 			then
 				dohwclock $HARDWARECLOCK systohc && NEXTITEM=3
@@ -184,6 +185,12 @@ interactive_prepare_disks ()
 	NEXTITEM=
 	DISK_CONFIG_TYPE=
 	[ "$BLOCK_ROLLBACK_USELESS" = "0" ] && show_warning "Rollback may be needed" "It seems you already went here.  You should probably rollback previous changes before reformatting, otherwise stuff will probably fail"
+	[ -z "$PART_ACCESS" ] && PART_ACCESS=dev
+	ask_option $PART_ACCESS 'Partition Access Method' 'How do you want your partitions to be accessed in grubs menu.lst and /etc/fstab?' '' \
+		"dev"	"directly by /dev/* (most intuitive but devicefile names can change on kernel updates)" \
+		"label"	"by Disk-Label (Will use the filesystem labels where you give them, and fall back on 'dev' otherwise)" \
+		"uuid"	"by Universally Unique Identifier (You don't need to do anything, but doesn't look pretty)" || return 1
+	PART_ACCESS=$ANSWER_OPTION
 	while [ "$DONE" = "0" ]
 	do
 		rollbackstr=" (you don't need to do this)"
@@ -294,6 +301,7 @@ interactive_autoprepare()
 
 	ask_yesno "$DISC will be COMPLETELY ERASED!  Are you absolutely sure?" || return 1
 
+	PART_ACCESS=uuid
 
 	process_disks       || die_error "Something went wrong while partitioning"
 	if ! process_filesystems
@@ -477,8 +485,8 @@ interactive_filesystem ()
 		then
 			default=
 			[ -n "$fs_label" ] && default="$fs_label"
-			ask_string "Enter the label for this $fs_type on $part (optional)" "$default" 0
-			fs_label=$ANSWER_STRING
+			ask_string "Enter the label for this $fs_type on $part (optional) [keep it short and don't use spaces]" "$default" 0
+			fs_label=${ANSWER_STRING// } # strip spaces to prevent problems in our bash code and to keep things simple.
 		fi
 
 		# ask special params, if relevant
@@ -745,7 +753,7 @@ interactive_filesystems() {
 interactive_select_packages() {
 
 	# set up our install location if necessary and sync up so we can get package lists
-	target_prepare_pacman || ( show_warning 'Pacman preparation failure' "Pacman preparation failed! Check $LOG for errors." && return 1 )
+	target_prepare_pacman || { show_warning 'Pacman preparation failure' "Pacman preparation failed! Check $LOG for errors."; return 1; }
 
 	repos=`list_pacman_repos target`
 	notify "Package selection is split into two stages.  First you will select package groups that contain packages you may be interested in.  Then you will be presented with a full list of packages for each group, allowing you to fine-tune.\n\n
@@ -1087,11 +1095,21 @@ generate_grub_menulst() {
             # remove default entries by truncating file at our little tag (#-*)
             sed -i -e '/#-\*/q' $grubmenu
 
-        # attempt to use a UUID if the root device has one
-        local _uuid="$(getuuid ${_rootpart})"
-        if [ -n "${_uuid}" ]; then
-            _rootpart="/dev/disk/by-uuid/${_uuid}"
-        fi
+	# find label or uuid of the root partition
+	case $PART_ACCESS in
+		label)
+			local _label="$(getlabel $_rootpart)"
+			if [ -n "${_label}" ]; then
+			    _rootpart="/dev/disk/by-label/${_label}"
+			fi
+			;;
+		uuid)
+			local _uuid="$(getuuid $_rootpart)"
+			if [ -n "${_uuid}" ]; then
+			    _rootpart="/dev/disk/by-uuid/${_uuid}"
+			fi
+			;;
+	esac
 
 		# handle dmraid/mdadm,lvm,dm_crypt etc. replace entries where needed automatically
 		kernel="kernel $subdir/vmlinuz26 root=${_rootpart} ro"
